pub struct ContractCall<T> { /* private fields */ }Implementations
Sourceimpl<T> ContractCall<T>
impl<T> ContractCall<T>
pub fn with_user(self, account: &Account) -> Self
pub fn args(self, args: Vec<u8>) -> Self
Sourcepub fn args_json<U: Serialize>(self, args: U) -> Result<Self>
pub fn args_json<U: Serialize>(self, args: U) -> Result<Self>
Similar to args, specify an argument that is JSON serializable and can be
accepted by the equivalent contract. Recommend to use something like
serde_json::json! macro to easily serialize the arguments.
Sourcepub fn deposit(self, deposit: NearToken) -> Self
pub fn deposit(self, deposit: NearToken) -> Self
Specify the amount of tokens to be deposited where deposit is the amount of
tokens in yocto near.
pub fn gas(self, gas: Gas) -> Self
Sourceimpl<T: Send + DeserializeOwned> ContractCall<T>
impl<T: Send + DeserializeOwned> ContractCall<T>
pub async fn result(self) -> Result<ExecutionSuccess, ExecutionFailure>
pub async fn expect_error(self, error_message: &str) -> Result<()>
pub async fn expect_log(self, log: &str) -> Result<()>
pub async fn dont_expect_log(self, log: &str) -> Result<()>